@@ -4,20 +4,19 @@
  *
  * Copyright (C) 2002 Gustavo Giráldez <gustavo.giraldez@gmx.net>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,7 +29,6 @@
 #include <libxml/parser.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnome/gnome-macros.h>
 
 #include "gdl-dock-layout.h"
 #include "gdl-tools.h"
@@ -110,7 +108,7 @@ static void     gdl_dock_layout_build_models    (GdlDockLayout      *layout);
 
 /* ----- Private implementation ----- */
 
-GNOME_CLASS_BOILERPLATE (GdlDockLayout, gdl_dock_layout, GObject, G_TYPE_OBJECT);
+GDL_CLASS_BOILERPLATE (GdlDockLayout, gdl_dock_layout, GObject, G_TYPE_OBJECT);
 
 static void
 gdl_dock_layout_class_init (GdlDockLayoutClass *klass)
@@ -227,9 +225,9 @@ gdl_dock_layout_build_doc (GdlDockLayout *layout)
 {
     g_return_if_fail (layout->_priv->doc == NULL);
 
-    layout->_priv->doc = xmlNewDoc ("1.0");
+    layout->_priv->doc = xmlNewDoc (BAD_CAST "1.0");
     layout->_priv->doc->children = xmlNewDocNode (layout->_priv->doc, NULL, 
-                                                  ROOT_ELEMENT, NULL);
+                                                  BAD_CAST ROOT_ELEMENT, NULL);
 }
 
 static xmlNodePtr
@@ -247,9 +245,9 @@ gdl_dock_layout_find_layout (GdlDockLayout *layout,
     /* get document root */
     node = layout->_priv->doc->children;
     for (node = node->children; node; node = node->next) {
-        gchar *layout_name;
+        xmlChar *layout_name;
         
-        if (strcmp (node->name, LAYOUT_ELEMENT_NAME))
+        if (strcmp ((char*)node->name, LAYOUT_ELEMENT_NAME))
             /* skip non-layout element */
             continue;
 
@@ -257,8 +255,8 @@ gdl_dock_layout_find_layout (GdlDockLayout *layout,
         if (!name)
             break;
 
-        layout_name = xmlGetProp (node, NAME_ATTRIBUTE_NAME);
-        if (!strcmp (name, layout_name))
+        layout_name = xmlGetProp (node, BAD_CAST NAME_ATTRIBUTE_NAME);
+        if (!strcmp (name, (char*)layout_name))
             found = TRUE;
         xmlFree (layout_name);
 
@@ -338,7 +336,7 @@ update_items_model (GdlDockLayout *layout)
                 if (l) {
                     /* found, update data */
                     g_object_get (item, 
-                                  "long_name", &long_name, 
+                                  "long-name", &long_name, 
                                   "locked", &locked, 
                                   NULL);
                     gtk_list_store_set (store, &iter, 
@@ -370,7 +368,7 @@ update_items_model (GdlDockLayout *layout)
         GdlDockObject *object = l->data;
         
         g_object_get (object, 
-                      "long_name", &long_name, 
+                      "long-name", &long_name, 
                       "locked", &locked, 
                       NULL);
         gtk_list_store_append (store, &iter);
@@ -661,7 +659,7 @@ cell_edited_cb (GtkCellRendererText *cell,
     g_free (name);
     g_return_if_fail (node != NULL);
 
-    xmlSetProp (node, NAME_ATTRIBUTE_NAME, new_text);
+    xmlSetProp (node, BAD_CAST NAME_ATTRIBUTE_NAME, BAD_CAST new_text);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter, COLUMN_NAME, new_text,
                         COLUMN_EDITABLE, TRUE, -1);
 
@@ -694,7 +692,7 @@ gdl_dock_layout_construct_layouts_ui (GdlDockLayout *layout)
     ui_data->layout = layout;
     g_object_add_weak_pointer (G_OBJECT (layout),
                                (gpointer *) &ui_data->layout);
-    g_object_set_data (G_OBJECT (container), "ui_data", ui_data);
+    g_object_set_data (G_OBJECT (container), "ui-data", ui_data);
     
     /* get ui widget references */
     layouts_list = glade_xml_get_widget (gui, "layouts_list");
@@ -770,15 +768,15 @@ gdl_dock_layout_setup_object (GdlDockMaster *master,
     GObjectClass  *object_class = NULL;
 
     GParamSpec   **props;
-    gint           n_props, i;
+    guint          n_props, i;
     GParameter    *params = NULL;
     gint           n_params = 0;
     GValue         serialized = { 0, };
     
-    object_name = xmlGetProp (node, GDL_DOCK_NAME_PROPERTY);
-    if (object_name && strlen (object_name) > 0) {
+    object_name = xmlGetProp (node, BAD_CAST GDL_DOCK_NAME_PROPERTY);
+    if (object_name && strlen ((char*)object_name) > 0) {
         /* the object must already be bound to the master */
-        object = gdl_dock_master_get_object (master, object_name);
+        object = gdl_dock_master_get_object (master, (char*)object_name);
 
         xmlFree (object_name);
         object_type = object ? G_TYPE_FROM_INSTANCE (object) : G_TYPE_NONE;
@@ -786,7 +784,7 @@ gdl_dock_layout_setup_object (GdlDockMaster *master,
     else {
         /* the object should be automatic, so create it by
            retrieving the object type from the dock registry */
-        object_type = gdl_dock_object_type_from_nick (node->name);
+        object_type = gdl_dock_object_type_from_nick ((char*)node->name);
         if (object_type == G_TYPE_NONE) {
             g_warning (_("While loading layout: don't know how to create "
                          "a dock object whose nick is '%s'"), node->name);
@@ -819,9 +817,9 @@ gdl_dock_layout_setup_object (GdlDockMaster *master,
             continue;
 
         /* get the property from xml if there is one */
-        xml_prop = xmlGetProp (node, props [i]->name);
+        xml_prop = xmlGetProp (node, BAD_CAST props [i]->name);
         if (xml_prop) {
-            g_value_set_static_string (&serialized, xml_prop);
+            g_value_set_static_string (&serialized, (char*)xml_prop);
             
             if (!GDL_DOCK_PARAM_CONSTRUCTION (props [i]) &&
                 (props [i]->flags & GDL_DOCK_PARAM_AFTER)) {
@@ -976,7 +974,7 @@ gdl_dock_layout_foreach_object_save (GdlDockObject *object,
     } *info = user_data, info_child;
 
     xmlNodePtr   node;
-    gint         n_props, i;
+    guint        n_props, i;
     GParamSpec **props;
     GValue       attr = { 0, };
     
@@ -985,8 +983,8 @@ gdl_dock_layout_foreach_object_save (GdlDockObject *object,
     
     node = xmlNewChild (info->where,
                         NULL,               /* ns */
-                        gdl_dock_object_nick_from_type (G_TYPE_FROM_INSTANCE (object)),
-                        NULL);              /* contents */
+                        BAD_CAST gdl_dock_object_nick_from_type (G_TYPE_FROM_INSTANCE (object)),
+                        BAD_CAST NULL);     /* contents */
 
     /* get object exported attributes */
     props = g_object_class_list_properties (G_OBJECT_GET_CLASS (object),
@@ -1010,7 +1008,7 @@ gdl_dock_layout_foreach_object_save (GdlDockObject *object,
             if (strcmp (p->name, GDL_DOCK_NAME_PROPERTY) ||
                 g_value_get_string (&v)) {
                 if (g_value_transform (&v, &attr))
-                    xmlSetProp (node, p->name, g_value_get_string (&attr));
+                    xmlSetProp (node, BAD_CAST p->name, BAD_CAST g_value_get_string (&attr));
             }
             
             /* free the parameter value */
@@ -1153,7 +1151,7 @@ gdl_dock_layout_attach (GdlDockLayout *layout,
     layout->master = master;
     if (layout->master) {
         g_object_ref (layout->master);
-        g_signal_connect (layout->master, "layout_changed",
+        g_signal_connect (layout->master, "layout-changed",
                           (GCallback) gdl_dock_layout_layout_changed_cb,
                           layout);
     }
@@ -1217,8 +1215,8 @@ gdl_dock_layout_save_layout (GdlDockLayout *layout,
 
     /* create the new node */
     node = xmlNewChild (layout->_priv->doc->children, NULL, 
-                        LAYOUT_ELEMENT_NAME, NULL);
-    xmlSetProp (node, NAME_ATTRIBUTE_NAME, layout_name);
+                        BAD_CAST LAYOUT_ELEMENT_NAME, NULL);
+    xmlSetProp (node, BAD_CAST NAME_ATTRIBUTE_NAME, BAD_CAST layout_name);
 
     /* save the layout */
     gdl_dock_layout_save (layout->master, node);
@@ -1300,7 +1298,7 @@ gdl_dock_layout_load_from_file (GdlDockLayout *layout,
         if (layout->_priv->doc) {
             xmlNodePtr root = layout->_priv->doc->children;
             /* minimum validation: test the root element */
-            if (root && !strcmp (root->name, ROOT_ELEMENT)) {
+            if (root && !strcmp ((char*)root->name, ROOT_ELEMENT)) {
                 update_layouts_model (layout);
                 retval = TRUE;
             } else {
@@ -1364,14 +1362,14 @@ gdl_dock_layout_get_layouts (GdlDockLayout *layout,
 
     node = layout->_priv->doc->children;
     for (node = node->children; node; node = node->next) {
-        gchar *name;
+        xmlChar *name;
 
-        if (strcmp (node->name, LAYOUT_ELEMENT_NAME))
+        if (strcmp ((char*)node->name, LAYOUT_ELEMENT_NAME))
             continue;
 
-        name = xmlGetProp (node, NAME_ATTRIBUTE_NAME);
-        if (include_default || strcmp (name, DEFAULT_LAYOUT))
-            retval = g_list_prepend (retval, g_strdup (name));
+        name = xmlGetProp (node, BAD_CAST NAME_ATTRIBUTE_NAME);
+        if (include_default || strcmp ((char*)name, DEFAULT_LAYOUT))
+            retval = g_list_prepend (retval, g_strdup ((char*)name));
         xmlFree (name);
     };
     retval = g_list_reverse (retval);
