@@ -26,7 +26,6 @@
 
 #include <glib.h>
 #include <gtk/gtkwidget.h>
-#include <bonobo/bonobo-ui-component.h>
 
 /* FIXME: Toggle this */
 
@@ -138,7 +137,11 @@ type_as_function ## _get_type (void)
  * the _WITH_DEFAULT version for that */
 #define GDL_CALL_PARENT(parent_class_cast, name, args)          \
 	((parent_class_cast(parent_class)->name != NULL) ?      \
-	 parent_class_cast(parent_class)->name args : (void)0)
+	 parent_class_cast(parent_class)->name args : (void *)0)
+
+#define GDL_CALL_PARENT_GBOOLEAN(parent_class_cast, name, args)          \
+       ((parent_class_cast(parent_class)->name != NULL) ?      \
+        parent_class_cast(parent_class)->name args : (gboolean)0)
 
 /* Same as above, but in case there is no implementation, it evaluates
  * to def_return */
@@ -174,14 +177,7 @@ typedef struct _GdlPixmap {
 #define GDL_PIXMAP(path,fname)	{ (path), (fname), NULL }
 #define GDL_PIXMAP_END		{ NULL, NULL, NULL }
 
-/* Takes an array of pixmaps, terminated by GDL_PIXMAP_END, and loads into uic */
-void gdl_pixmaps_update (BonoboUIComponent *uic,
-			 const char        *pixmap_dir,
-			 GdlPixmap         *pixcache);
-
-GtkWidget *gdl_button_new_with_stock_image (const char *text,
-					    const char *stock_id);
-
 G_END_DECLS
 
 #endif
+
